

:py:mod:`holisticai.robustness.metrics`
=======================================

.. automodule:: holisticai.robustness.metrics
    :no-members:
    :no-inherited-members:

**Binary Classification**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/

    adversarial_accuracy
    empirical_robustness